**Example 1: 删除任务**



Input: 

```
tccli wedata DeleteOfflineTask --cli-unfold-argument  \
    --ProjectId xx \
    --VirtualFlag True \
    --OperatorName xx \
    --TaskId xx
```

Output: 
```
{
    "Response": {
        "Data": true,
        "RequestId": "xx"
    }
}
```

